==> google_applovin_unity_ads-2.1.9.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterFacebookBannerAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.facebook.ads.AdListener;
import com.facebook.ads.AdSize;
import com.facebook.ads.AdView;

import io.flutter.plugin.platform.PlatformView;
import io.flutter.util.Preconditions;

/**
 * A wrapper for {@link AdView}.
 */
class FlutterFacebookBannerAd extends FlutterAd implements FlutterAdLoadedListener {

    @NonNull
    private final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final FlutterAdSize size;
    @NonNull
    private final BannerAdCreator bannerAdCreator;
    @Nullable
    private AdView adView;

    /**
     * Constructs the FlutterBannerAd.
     */
    public FlutterFacebookBannerAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull FlutterAdSize size,
            @NonNull BannerAdCreator bannerAdCreator) {
        super(adId);
        Preconditions.checkNotNull(manager);
        Preconditions.checkNotNull(adUnitId);
        Preconditions.checkNotNull(size);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.size = size;
        this.bannerAdCreator = bannerAdCreator;
    }

    @Override
    public void onAdLoaded() {
        if (adView != null) {
            manager.onAdLoaded(adId, null);
        }
    }

    @Override
    void load() {
        final AdSize fbsize;
        if ( size.height == 250) {
            fbsize = AdSize.RECTANGLE_HEIGHT_250;
        } else if ( size.width == 90) {
            fbsize  = AdSize.BANNER_HEIGHT_90;
        } else if ( size.width == 50) {
            fbsize  = AdSize.BANNER_HEIGHT_50;
        } else {
            fbsize  = new AdSize( size.width,  size.height);
        }
        adView = bannerAdCreator.createFacebookAdView(adUnitId, fbsize);
        AdListener listener = new FlutterBannerAdListener(adId, manager, this);
        adView.loadAd(adView.buildLoadAdConfig().withAdListener(listener).build());
    }

    @Nullable
    @Override
    public PlatformView getPlatformView() {
        if (adView == null) {
            return null;
        }
        return new FlutterPlatformView(adView);
    }

    @Override
    void dispose() {
        if (adView != null) {
            adView.destroy();
            adView = null;
        }
    }

    @Nullable
    FlutterAdSize getAdSize() {
       return size;
    }
}

==> google_applovin_unity_ads-2.2.0.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterFacebookBannerAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.facebook.ads.AdListener;
import com.facebook.ads.AdSize;
import com.facebook.ads.AdView;

import io.flutter.plugin.platform.PlatformView;
import io.flutter.util.Preconditions;

/**
 * A wrapper for {@link AdView}.
 */
class FlutterFacebookBannerAd extends FlutterAd implements FlutterAdLoadedListener {

    @NonNull
    private final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final FlutterAdSize size;
    @NonNull
    private final BannerAdCreator bannerAdCreator;
    @Nullable
    private AdView adView;

    /**
     * Constructs the FlutterBannerAd.
     */
    public FlutterFacebookBannerAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull FlutterAdSize size,
            @NonNull BannerAdCreator bannerAdCreator) {
        super(adId);
        Preconditions.checkNotNull(manager);
        Preconditions.checkNotNull(adUnitId);
        Preconditions.checkNotNull(size);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.size = size;
        this.bannerAdCreator = bannerAdCreator;
    }

    @Override
    public void onAdLoaded() {
        if (adView != null) {
            manager.onAdLoaded(adId, null);
        }
    }

    @Override
    void load() {
        final AdSize fbsize;
        Log.e( "load: ",size.width+" ------- "+size.height);
        if ( size.height >= 250) {
            fbsize = AdSize.RECTANGLE_HEIGHT_250;
        } else if ( size.width >= 90) {
            fbsize  = AdSize.BANNER_HEIGHT_90;
        } else {
            fbsize  = AdSize.BANNER_HEIGHT_50;
        }

        adView = bannerAdCreator.createFacebookAdView(adUnitId, fbsize);
        AdListener listener = new FlutterBannerAdListener(adId, manager, this);
        adView.loadAd(adView.buildLoadAdConfig().withAdListener(listener).build());
    }

    @Nullable
    @Override
    public PlatformView getPlatformView() {
        if (adView == null) {
            return null;
        }
        return new FlutterPlatformView(adView);
    }

    @Override
    void dispose() {
        if (adView != null) {
            adView.destroy();
            adView = null;
        }
    }

    @Nullable
    FlutterAdSize getAdSize() {
       return size;
    }
}
